# AISuperServer

Es un experimento simple para crear una interfaz simple y rápida de server de Inferencia en Local, con Flask, Ollama, etc.

### Se recomienda instalar Ollama antes de empezar a ejecutar el servidor y hacer una config rapida con el modelo que vas a usar en Local
